<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package free1
 */

/**
 * Search Filter 
 */
if ( ! function_exists( 'free1_search_filter' ) ) :

function free1_search_filter($query) {
	if ($query->is_search) {
		$query->set('post_type', 'post');
	}
	return $query;
}

add_filter('pre_get_posts','free1_search_filter');

endif;

/**
 * Filter the except length to 20 characters.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
if ( ! function_exists( 'free1_custom_excerpt_length' ) ) :

function free1_custom_excerpt_length( $length ) {
    return get_theme_mod('entry-excerpt-length', '80');
}
add_filter( 'excerpt_length', 'free1_custom_excerpt_length', 999 );

endif;

/**
 * Customize excerpt more.
 */
if ( ! function_exists( 'free1_excerpt_more' ) ) :

function free1_excerpt_more( $more ) {
   return '... ';
}
add_filter( 'excerpt_more', 'free1_excerpt_more' );

endif;

/**
 * Display the first (single) category of post.
 */
if ( ! function_exists( 'free1_first_category' ) ) :
function free1_first_category() {
    $category = get_the_category();
    if ($category) {
      echo '<a target="_blank" href="' . get_category_link( $category[0]->term_id ) . '" title="' . sprintf( __( "查看所有%s文章", 'free-1' ), $category[0]->name ) . '" ' . '>' . $category[0]->name.'</a> ';
    }    
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
if ( ! function_exists( 'free1_categorized_blog' ) ) :

function free1_categorized_blog() {
    if ( false === ( $all_the_cool_cats = get_transient( 'free1_categories' ) ) ) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories( array(
            'fields'     => 'ids',
            'hide_empty' => 1,
            // We only need to know if there is more than one category.
            'number'     => 2,
        ) );

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count( $all_the_cool_cats );

        set_transient( 'free1_categories', $all_the_cool_cats );
    }

    if ( $all_the_cool_cats > 1 ) {
        // This blog has more than 1 category so free1_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so free1_categorized_blog should return false.
        return false;
    }
}

endif;

/**
 * Flush out the transients used in free1_categorized_blog.
 */
if ( ! function_exists( 'free1_category_transient_flusher' ) ) :

function free1_category_transient_flusher() {
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient( 'free1_categories' );
}
add_action( 'edit_category', 'free1_category_transient_flusher' );
add_action( 'save_post',     'free1_category_transient_flusher' );

endif;

/**
 * Disable specified widgets.
 */
if ( ! function_exists( 'free1_disable_specified_widgets' ) ) :

function free1_disable_specified_widgets( $sidebars_widgets ) {

    if ( isset($sidebars_widgets['header-ad']) ) {
        if ( is_array($sidebars_widgets['header-ad']) ) {
               foreach($sidebars_widgets['header-ad'] as $i => $widget) {
                    if( (strpos($widget, 'zhutibaba-') === false) ) {
                       unset($sidebars_widgets['header-ad'][$i]);
                    }
               }
        }     
    }             

    return $sidebars_widgets;
}
add_filter( 'sidebars_widgets', 'free1_disable_specified_widgets' );

endif;

/**
 * Add link to Admin Bar.
 */

if ( ! function_exists( 'free1_custom_toolbar_link' ) ) :

function free1_custom_toolbar_link($wp_admin_bar) {
    $args = array(
        'id' => 'zhutibaba',
        'title' => '主题巴巴 - 大师级WordPress主题', 
        'href' => 'https://www.zhutibaba.com/themes', 
        'meta' => array(
            'class' => 'zhutibaba', 
            'title' => '',
            'target'=> '_blank',
            )
    );
    $wp_admin_bar->add_node($args);
}
add_action('admin_bar_menu', 'free1_custom_toolbar_link', 999);

endif;

/**
 * Remove Admin Bar on Front-end.
 */
add_filter('show_admin_bar', '__return_false');
